==> bibledit-web-1.2.tar.gz: bibledit-web-1.2/web/notes/click.php <==
<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.
 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
  
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/


require_once ("../bootstrap/bootstrap.php");
page_access_level (CONSULTANT_LEVEL);
@$open = $_GET ['open'];
if (isset ($open)) {
  $open = intval (basename ($open));
  $database_notes = Database_Notes::getInstance ();
  if ($database_notes->identifierExists ($open)) {
    $ipc_notes = Ipc_Notes::getInstance ();
    $ipc_notes->open ($open);
  }
}
@$new = $_GET ['new'];
if (isset ($new)) {
  $new = intval (basename ($new));
  $database_changes = Database_Changes::getInstance ();
  $database_bibles = Database_Bibles::getInstance ();
  $bible = $database_changes->getBible ($new);
  $bible = $database_bibles->getName ($bible);
  $summary = gettext ("Query about a change in the text");
  $contents = "<p>" . gettext ("Old text:") . "</p>";
  $contents .= $database_changes->getOldText ($new);
  $contents .= "<p>" .  gettext ("Change:") . "</p>";
  $contents .= "<p>" . $database_changes->getModification ($new) . "</p>";
  $contents .= "<p>" . gettext ("New text:") . "</p>";
  $contents .= $database_changes->getNewText ($new);
  $passage = $database_changes->getPassage ($new);
  $database_notes = Database_Notes::getInstance ();
  $identifier = $database_notes->storeNewNote ($bible, $passage ['book'], $passage ['chapter'], $passage ['verse'], $summary, $contents, false);
  $notes_logic = Notes_Logic::getInstance();
  $notes_logic->handlerNewNote ($identifier);
  $ipc_notes = Ipc_Notes::getInstance ();
  $ipc_notes->open ($identifier);
}
?>

==> bibledit-web-1.3.tar.gz: bibledit-web-1.3/web/notes/click.php <==
<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.
 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
  
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/


require_once ("../bootstrap/bootstrap.php");
page_access_level ((Filter_Roles::CONSULTANT_LEVEL));
@$open = $_GET ['open'];
if (isset ($open)) {
  $open = intval (basename ($open));
  $database_notes = Database_Notes::getInstance ();
  if ($database_notes->identifierExists ($open)) {
    $ipc_notes = Ipc_Notes::getInstance ();
    $ipc_notes->open ($open);
  }
}
@$new = $_GET ['new'];
if (isset ($new)) {
  $new = intval (basename ($new));
  $database_changes = Database_Changes::getInstance ();
  $database_bibles = Database_Bibles::getInstance ();
  $bible = $database_changes->getBible ($new);
  $bible = $database_bibles->getName ($bible);
  $summary = gettext ("Query about a change in the text");
  $contents = "<p>" . gettext ("Old text:") . "</p>";
  $contents .= $database_changes->getOldText ($new);
  $contents .= "<p>" .  gettext ("Change:") . "</p>";
  $contents .= "<p>" . $database_changes->getModification ($new) . "</p>";
  $contents .= "<p>" . gettext ("New text:") . "</p>";
  $contents .= $database_changes->getNewText ($new);
  $passage = $database_changes->getPassage ($new);
  $database_notes = Database_Notes::getInstance ();
  $identifier = $database_notes->storeNewNote ($bible, $passage ['book'], $passage ['chapter'], $passage ['verse'], $summary, $contents, false);
  $notes_logic = Notes_Logic::getInstance();
  $notes_logic->handlerNewNote ($identifier);
  $ipc_notes = Ipc_Notes::getInstance ();
  $ipc_notes->open ($identifier);
}
?>
